==> haskell-emojis-0.1.4.1-81-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-emojis.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 emojis
version:              0.1.4.1
visibility:           public
id:                   emojis-0.1.4.1-VOXDtaadLD4hNN8sCPzYl
key:                  emojis-0.1.4.1-VOXDtaadLD4hNN8sCPzYl
license:              BSD-3-Clause
copyright:            2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/emojis#readme
synopsis:             Conversion between emoji characters and their names.
description:
    This package provides functions for converting
    emoji names to emoji characters and vice versa.

    How does it differ from the @emoji@ package?

    -   It supports a fuller range of emojis, including all those
    supported by GitHub
    -   It supports lookup of emoji aliases from emoji
    -   It uses Text rather than String
    -   It has a lighter dependency footprint: in particular, it
    does not require aeson
    -   It does not require TemplateHaskell

category:             Text
abi:                  f94e18e6d4f07924495b0a29bccf1058
exposed:              True
exposed-modules:      Text.Emoji
hidden-modules:       Trie
import-dirs:          /usr/lib/ghc-9.6.6/site-local/emojis-0.1.4.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/emojis-0.1.4.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/emojis-0.1.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-emojis
hs-libraries:         HSemojis-0.1.4.1-VOXDtaadLD4hNN8sCPzYl
depends:              base-4.18.2.1 containers-0.6.7 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-emojis/html/emojis.haddock
haddock-html:         /usr/share/doc/haskell-emojis/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-emojis-0.1.4.1-82-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-emojis.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 emojis
version:              0.1.4.1
visibility:           public
id:                   emojis-0.1.4.1-L7mOnPsQOMB2xPGhke4egp
key:                  emojis-0.1.4.1-L7mOnPsQOMB2xPGhke4egp
license:              BSD-3-Clause
copyright:            2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/emojis#readme
synopsis:             Conversion between emoji characters and their names.
description:
    This package provides functions for converting
    emoji names to emoji characters and vice versa.

    How does it differ from the @emoji@ package?

    -   It supports a fuller range of emojis, including all those
    supported by GitHub
    -   It supports lookup of emoji aliases from emoji
    -   It uses Text rather than String
    -   It has a lighter dependency footprint: in particular, it
    does not require aeson
    -   It does not require TemplateHaskell

category:             Text
abi:                  8f34efbfe75aff0b3a9190a0f79e6ca5
exposed:              True
exposed-modules:      Text.Emoji
hidden-modules:       Trie
import-dirs:          /usr/lib/ghc-9.6.6/site-local/emojis-0.1.4.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/emojis-0.1.4.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/emojis-0.1.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-emojis
hs-libraries:         HSemojis-0.1.4.1-L7mOnPsQOMB2xPGhke4egp
depends:              base-4.18.2.1 containers-0.6.7 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-emojis/html/emojis.haddock
haddock-html:         /usr/share/doc/haskell-emojis/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
